This part of the project documentation is a
reference for the technical implementation of the `VoDEx` project code.

# core
::: src.vodex.core
    options:
      members:
        - None
      show_root_heading: false
      show_source:

# experiment
::: src.vodex.experiment
    options:
      members:
        - None
      show_root_heading: false
      show_source: false

# loaders
::: src.vodex.loaders
    options:
      members:
        - None
      show_root_heading: false
      show_source: false

# dbmethods
::: src.vodex.dbmethods
    options:
      members:
        - None
      show_root_heading: false
      show_source: false
